@@ -28,7 +28,7 @@ Net::XMPP::JID - XMPP JID Module
 =head1 SYNOPSIS
 
   Net::XMPP::JID is a companion to the Net::XMPP module.
-  It provides the user a simple interface to set and retrieve all 
+  It provides the user a simple interface to set and retrieve all
   parts of a Jabber ID (userid on a server).
 
 =head1 DESCRIPTION
@@ -88,12 +88,12 @@ Net::XMPP::JID - XMPP JID Module
 
   GetUserID() - returns a string with the userid of the JID.
                 If the string is an address (bob%jabber.org) then
-                the function will return it as an address 
+                the function will return it as an address
                 (bob@jabber.org).
 
   GetServer() - returns a string with the server of the JID.
 
-  GetResource() - returns a string with the resource of the JID. 
+  GetResource() - returns a string with the resource of the JID.
 
   GetJID()       - returns a string that represents the JID stored
   GetJID("full")   within.  If the "full" string is specified, then
@@ -112,16 +112,16 @@ Net::XMPP::JID - XMPP JID Module
                              the server, and then set the resource
                              then both will be in the jid.  If all
                              you pass is a string, then that string
-                             is used as the JID.  For valid settings 
+                             is used as the JID.  For valid settings
                              read the specific Set functions below.
 
   SetUserID(string) - sets the userid.  Must be a valid userid or the
                       server will complain if you try to use this JID
-                      to talk to the server.  If the string is an 
+                      to talk to the server.  If the string is an
                       address then it will be converted to the %
                       form suitable for using as a User ID.
 
-  SetServer(string) - sets the server.  Must be a valid host on the 
+  SetServer(string) - sets the server.  Must be a valid host on the
                       network or the server will not be able to talk
                       to it.
 
@@ -129,12 +129,16 @@ Net::XMPP::JID - XMPP JID Module
 
 =head1 AUTHOR
 
-Ryan Eatmon
+Originally authored by Ryan Eatmon.
+
+Previously maintained by Eric Hacker. 
+
+Currently maintained by Darian Anthony Patrick.
 
 =head1 COPYRIGHT
 
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This module is free software, you can redistribute it and/or modify it
+under the LGPL 2.1.
 
 =cut
 
@@ -282,7 +286,7 @@ sub SetJID
     my $self = shift;
     my %jid;
 
-    if ($#_ > 0 ) { 
+    if ($#_ > 0 ) {
         while($#_ >= 0) { $jid{ lc pop(@_) } = pop(@_); }
 
         $self->SetUserID($jid{userid}) if exists($jid{userid});
