@@ -29,7 +29,7 @@ Net::XMPP::Roster - XMPP Roster Object
 
   Net::XMPP::Roster is a module that provides a developer an easy
   interface to an XMPP roster.  It provides high level functions to
-  query, update, and manage a user's roster.  
+  query, update, and manage a user's roster.
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,7 @@ Net::XMPP::Roster - XMPP Roster Object
   with a user's roster.  When you instantiate it, it automatically
   registers with the connection to receivce the correct packets so
   that it can track all roster updates, and presence packets.
-  
+
 =head2 Basic Functions
 
   my $Client = new Net::XMPP::Client(...);
@@ -90,7 +90,7 @@ Net::XMPP::Roster - XMPP Roster Object
 
   These functions are only needed if you want to manually control
   the Roster.
-  
+
   $Roster->add('bob@jabber.org',
                name=>"Bob",
                groups=>["Friends"]
@@ -130,7 +130,7 @@ Net::XMPP::Roster - XMPP Roster Object
   exists(jid) - return 1 if the JID exists in the database, undef
                 otherwise.  The jid can either be a string, or a
                 Net::XMPP::JID object.
-                
+
   groupExists(group) - return 1 if the group exists in the database,
                        undef otherwise.
 
@@ -208,18 +208,24 @@ handler(packet) - Take either a Net::XMPP::IQ or Net::XMPP::Presence
 
 =head1 AUTHOR
 
-Ryan Eatmon
+Originally authored by Ryan Eatmon.
+
+Previously maintained by Eric Hacker. 
+
+Currently maintained by Darian Anthony Patrick.
 
 =head1 COPYRIGHT
 
-This module is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This module is free software, you can redistribute it and/or modify it
+under the LGPL 2.1.
 
 =cut
 
 use strict;
 use Carp;
 
+use Net::XMPP::JID;
+
 sub new
 {
     my $proto = shift;
@@ -235,11 +241,11 @@ sub new
     }
 
     $self->{CONNECTION} = $args{connection};
-    
+
     bless($self, $proto);
 
     $self->init();
-    
+
     return $self;
 }
 
@@ -268,13 +274,16 @@ sub add
     my $self = shift;
     my ($jid,%item) = @_;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     $self->{JIDS}->{$jid} = \%item;
 
-    foreach my $group (@{$item{groups}})
+    if (exists($item{groups}))
     {
-        $self->{GROUPS}->{$group}->{$jid} = 1;
+        foreach my $group (@{$item{groups}})
+        {
+            $self->{GROUPS}->{$group}->{$jid} = 1;
+        }
     }
 }
 
@@ -292,7 +301,7 @@ sub addResource
     my $resource = shift;
     my (%item) = @_;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     my $priority = $item{priority};
     $priority = 0 unless defined($priority);
@@ -346,8 +355,8 @@ sub exists
     my $self = shift;
     my ($jid) = @_;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
-    
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
+
     return unless exists($self->{JIDS});
     return unless exists($self->{JIDS}->{$jid});
     return 1;
@@ -423,7 +432,7 @@ sub handleIQ
     my $self = shift;
     my $iq = shift;
 
-    print "handleIQ: iq(",$iq->GetXML(),")\n";
+    $self->{CONNECTION}->{DEBUG}->Log3('handleIQ: iq(' . $iq->GetXML() . ')');
 
     my $type = $iq->GetType();
     return unless (($type eq "set") || ($type eq "result"));
@@ -461,7 +470,7 @@ sub handlePresence
     my $self = shift;
     my $presence = shift;
 
-    print "handlePresence: presence(",$presence->GetXML(),")\n";
+    $self->{CONNECTION}->{DEBUG}->Log3('handlePresence: presence(' . $presence->GetXML() . ')');
 
     my $type = $presence->GetType();
     $type = "" unless defined($type);
@@ -473,7 +482,7 @@ sub handlePresence
 
     my $resource = $jid->GetResource();
     $resource = " " unless ($resource ne "");
-    
+
     $jid = $jid->GetJID();
     $jid = "" unless defined($jid);
 
@@ -489,7 +498,7 @@ sub handlePresence
     if (($type eq "") || ($type eq "available"))
     {
         my %item;
-        
+
         $item{priority} = $presence->GetPriority();
         $item{priority} = 0 unless defined($item{priority});
 
@@ -531,7 +540,7 @@ sub jids
             push(@jids,new Net::XMPP::JID($jid));
         }
     }
-    
+
     if ($type eq "group")
     {
         return () unless exists($self->{GROUPS});
@@ -558,7 +567,7 @@ sub online
     my $self = shift;
     my $jid = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return unless $self->exists($jid);
 
@@ -580,15 +589,15 @@ sub priority
     my $jid = shift;
     my $resource = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
-    
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
+
     if (defined($resource))
     {
         return unless $self->resourceExists($jid,$resource);
         return unless exists($self->{JIDS}->{$jid}->{resources}->{$resource}->{priority});
         return $self->{JIDS}->{$jid}->{resources}->{$resource}->{priority};
     }
-    
+
     return unless exists($self->{JIDS}->{$jid}->{priorities});
     my @priorities = sort{ $b <=> $a } keys(%{$self->{JIDS}->{$jid}->{priorities}});
     return $priorities[0];
@@ -606,8 +615,8 @@ sub query
     my $jid = shift;
     my $key = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
-    
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
+
     return unless $self->exists($jid);
     if (defined($key))
     {
@@ -628,12 +637,12 @@ sub remove
     my $self = shift;
     my $jid = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     if ($self->exists($jid))
     {
         $self->{CONNECTION}->{DEBUG}->Log3("Roster::remove: deleting $jid from the DB");
-        
+
         if (defined($self->query($jid,"groups")))
         {
             foreach my $group (@{$self->query($jid,"groups")})
@@ -645,7 +654,7 @@ sub remove
                     if (scalar(keys(%{$self->{GROUPS}})) == 0);
             }
         }
-    
+
         delete($self->{JIDS}->{$jid});
         delete($self->{JIDS}) if (scalar(keys(%{$self->{JIDS}})) == 0);
     }
@@ -663,7 +672,7 @@ sub removeResource
     my $jid = shift;
     my $resource = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     if ($self->resourceExists($jid,$resource))
     {
@@ -680,7 +689,7 @@ sub removeResource
                 $loc = $index
                     if ($self->{JIDS}->{$jid}->{priorities}->{$oldPriority}->[$index]->{resource} eq $resource);
             }
-            
+
             splice(@{$self->{JIDS}->{$jid}->{priorities}->{$oldPriority}},$loc,1);
 
             delete($self->{JIDS}->{$jid}->{priorities}->{$oldPriority})
@@ -704,7 +713,7 @@ sub resource
     my $self = shift;
     my $jid = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return unless $self->exists($jid);
 
@@ -726,8 +735,8 @@ sub resourceExists
     my $self = shift;
     my $jid = shift;
     my $resource = shift;
-    
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return unless $self->exists($jid);
     return unless exists($self->{JIDS}->{$jid}->{resources});
@@ -748,8 +757,8 @@ sub resourceQuery
     my $resource = shift;
     my $key = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
-    
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
+
     return unless $self->resourceExists($jid,$resource);
     if (defined($key))
     {
@@ -770,7 +779,7 @@ sub resources
     my $self = shift;
     my $jid = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return () unless $self->exists($jid);
 
@@ -803,7 +812,7 @@ sub resourceStore
     my $key = shift;
     my $value = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return unless defined($key);
     return unless defined($value);
@@ -827,7 +836,7 @@ sub store
     my $key = shift;
     my $value = shift;
 
-    $jid = $jid->GetJID() if $jid->isa("Net::XMPP::JID");
+    $jid = $jid->GetJID() if (ref $jid && $jid->isa('Net::XMPP::JID'));
 
     return unless defined($key);
     return unless defined($value);
